# civic-lib-core

[![PyPI](https://img.shields.io/pypi/v/civic-lib-core.svg)](https://pypi.org/project/civic-lib-core/)
[![Python versions](https://img.shields.io/pypi/pyversions/civic-lib-core.svg)](https://pypi.org/project/civic-lib-core/)
[![License: MIT](https://img.shields.io/badge/license-MIT-green.svg)](https://opensource.org/licenses/MIT)
[![CI Status](https://github.com/civic-interconnect/civic-lib-core/actions/workflows/ci.yml/badge.svg)](https://github.com/civic-interconnect/civic-lib-core/actions/workflows/ci.yml)
[![Docs](https://img.shields.io/badge/docs-mkdocs--material-blue)](https://civic-interconnect.github.io/civic-lib-core/)

> Shared internal utility library for [Civic Interconnect](https://github.com/civic-interconnect) projects

## Installation

```shell
uv add civic-lib-core
```

Or add to pyproject.toml dependencies.

## Development

See [DEVELOPER.md](./DEVELOPER.md)
